@@ -421,7 +421,10 @@ def ubuntu_1310_transform(click_manifest):
         else:
             newp.template = "ubuntu-sdk"
 
-        newp.policyvendor = "ubuntu"
+        if 'policy_vendor' in profile:
+            newp.policyvendor = profile['policy_vendor']
+        else:
+            newp.policyvendor = "ubuntu"
 
         if 'policy_version' in profile:
             newp.policyversion = profile['policy_version']
