@@ -431,68 +431,46 @@ class T(unittest.TestCase):
                           "Expected to get %s, got %s" % (expected,
                                                           easyprof_manifest))
 
-    def _test_bad_json_noname(self):
-        '''test for missing name field'''
-        rawinput = """
-{
-  "version": "0.1",
-  "maintainer": "Your Name <your.name@example.com>",
-  "title": "My Cool App",
-  "framework": "not-ubuntu-sdk-13.10",
-  "security": {
-    "profiles": {
+    def test_parse_security_manifest_alternative_policy_vendor(self):
+        '''Test that an alternative vendor is ok'''
+
+        c = self.clickstate
+        appname = "com.ubuntu.developer.trusteddev.terminal"
+        c.add_package(appname, "0.99.9~123")
+        security_json = '''{
+  "template": "unconfined",
+  "policy_groups": [ ],
+  "policy_version": "1.0",
+  "policy_vendor": "somevendor"
+}'''
+        c.add_app('0wnzered', manifest=security_json)
+
+        cm = apparmor.click.ClickManifest(os.path.join(c.click_dir,
+                                          "%s_0wnzered_0.99.9~123.json" %
+                                          (appname)))
+        easyprof_manifest = apparmor.click.transform(cm)
+
+        dbus_id = apparmor.click.dbus_path("%s_0wnzered_0.99.9~123" % appname)
+
+        expected = json.loads('''{
+  "profiles": {
+    "%s_0wnzered_0.99.9~123": {
+      "policy_groups": [ ],
+      "policy_vendor": "somevendor",
+      "policy_version": "1.0",
+      "template": "unconfined",
+      "template_variables": {
+        "APP_ID_DBUS": "%s",
+        "APP_PKGNAME": "%s",
+        "APP_VERSION": "0.99.9~123",
+        "CLICK_DIR": "%s"
+      }
     }
   }
-}"""
-        json_in = json.loads(rawinput)
-        try:
-            click.transform(json_in)
-        except click.AppArmorException:
-            return
-        except Exception:
-            raise
-        raise Exception("Framework should be invalid")
-
-    def _test_bad_json_noversion(self):
-        '''test for missing version field'''
-        rawinput = """
-{
-  "name": "com.ubuntu.developer.username.myapp",
-  "maintainer": "Your Name <your.name@example.com>",
-  "title": "My Cool App",
-  "framework": "not-ubuntu-sdk-13.10",
-  "security": {
-    "profiles": {
-    }
-  }
-}"""
-        json_in = json.loads(rawinput)
-        try:
-            click.transform(json_in)
-        except click.AppArmorException:
-            return
-        except Exception:
-            raise
-        raise Exception("Framework should be invalid")
-
-    def _test_bad_json_nosecurity(self):
-        '''test for missing security struct'''
-        rawinput = """
-{
-  "name": "com.ubuntu.developer.username.myapp",
-  "version": "0.1",
-  "maintainer": "Your Name <your.name@example.com>",
-  "title": "My Cool App",
-  "framework": "not-ubuntu-sdk-13.10"
-}"""
-        json_in = json.loads(rawinput)
-        try:
-            click.transform(json_in)
-        except click.AppArmorException:
-            return
-        except Exception:
-            raise
-        raise Exception("Framework should be invalid")
+}''' % (appname, dbus_id, appname, c.packages_tree))
+        self.assertEquals(expected, easyprof_manifest,
+                          "Expected to get %s, got %s" % (expected,
+                                                          easyprof_manifest))
 
 
 class AppArmorManifestSynchronization(unittest.TestCase):
